@@ -8,7 +8,8 @@ from rich.table import Table
 from shellpython.helpers import Dir
 from simple_term_menu import TerminalMenu
 
-from pbsrollout.k8s_utils import get_all_pbs_daemonset, delete_pbs_daemonset, get_all_pblog_daemonset, get_services
+from pbsrollout.k8s_utils import get_all_pbs_daemonset, get_all_pblog_daemonset, get_services, \
+    get_all_prebid_daemonset_V2, delete_namespaced_daemonset
 from pbsrollout.utils import Error, print_error_body, clean_stderr
 
 
@@ -17,7 +18,7 @@ def launch_pods(name: str, path: str, api_client: ApiClient) -> bool:
         print(f'\tLaunching new pods for cluster {name}')
         # run make clean deploy-new-pbs-prod
         cmd = "direnv exec . make clean deploy-new-pbs-prod"
-        ret = subprocess.run(cmd.split(" "), stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True, timeout=30)
+        ret = subprocess.run(cmd.split(" "), stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True, timeout=90)
         ret.stderr = clean_stderr(ret.stderr)
         if ret.returncode != 0 or ret.stderr != "":
             print_error_body(f"ERROR:\n\nstdout:\n{ret.stdout}\nstderr:\n{ret.stderr}")
@@ -129,7 +130,7 @@ def cutover_service(name: str, path: str, api_client: ApiClient) -> Status:
         # do the cutover
         # make next-pbs-prod-service
         cmd = "direnv exec . make deploy-new-pbs-prod-service"
-        ret = subprocess.run(cmd.split(" "), stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True, timeout=30, input='y')
+        ret = subprocess.run(cmd.split(" "), stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True, timeout=90, input='y')
         ret.stderr = clean_stderr(ret.stderr)
         if ret.returncode != 0 or ret.stderr != "":
             print_error_body(f"ERROR:\n\nstdout:\n{ret.stdout}\nstderr:\n{ret.stderr}")
@@ -151,14 +152,25 @@ def remove_old_pods(name: str, path: str, api_client: ApiClient) -> Error:
         console.print(f'\t\t[grey66]currently selected version: {selected_version}')
 
         # 2. Get all daemonsets
-        pbs_daemonsets = get_all_pbs_daemonset(api_client)
+        pbs_daemonsets = get_all_prebid_daemonset_V2(api_client)
         pbs_daemonsets_names = [d.metadata.name for d in pbs_daemonsets]
-        console.print(f'\t\tdaemonsets found: {pbs_daemonsets_names}')
-        if len(pbs_daemonsets_names) != 2:
-            return f'2 pbs daemonset expected (old/new). found: {pbs_daemonsets_names}'
+        pbs_daemonsets_names_by_version = dict()
+        for name in pbs_daemonsets_names:
+            # name is like: 'pblog-prod-v1104'.
+            version = name.split('-')[-1]
+            if version not in pbs_daemonsets_names_by_version:
+                pbs_daemonsets_names_by_version[version] = []
+            pbs_daemonsets_names_by_version[version].append(name)
 
-        version1 = int(pbs_daemonsets_names[0].replace('pbs-prod-v', ''))
-        version2 = int(pbs_daemonsets_names[1].replace('pbs-prod-v', ''))
+        console.print(f'\t\tdaemonsets found:\n' + '\n'.join(f'\t- {version}: {pbs_daemonsets_names_by_version[version]}' for version in pbs_daemonsets_names_by_version))
+        if len(pbs_daemonsets_names_by_version) != 1:
+            return f'2 pbs daemonset expected (old version/new version). found:\n' + '\n'.join(f'\t- {version}: {pbs_daemonsets_names_by_version[version]}' for version in pbs_daemonsets_names_by_version)
+
+        pbs_daemonsets_names_by_version['v3'] = ['abc']
+
+        all_versions = list(pbs_daemonsets_names_by_version.keys())
+        version1 = int(all_versions[0].replace('v', ''))
+        version2 = int(all_versions[1].replace('v', ''))
 
         # remove the oldest version THAT IS NOT SELECTED
         if version1 == selected_version and version2 > selected_version:
@@ -168,9 +180,21 @@ def remove_old_pods(name: str, path: str, api_client: ApiClient) -> Error:
         if selected_version != version1 and selected_version != version2:
             return f'selected version {selected_version} doesnt match the 2 existing versions: {[version1, version2]} from {pbs_daemonsets_names}'
 
+
         # remove the oldest version
         version_to_remove = version1 if selected_version == version2 else version2
-        console.print(f'\t\tremoving old version {version_to_remove}')
-        delete_pbs_daemonset(api_client, version_to_remove)
+        pbs_daemonsets_to_remove = pbs_daemonsets_names_by_version['v' + str(version_to_remove)]
+
+        terminal_menu = TerminalMenu(["[y] yes", "[n] no"],
+                                     title=f"Can we delete those this service {version_to_remove} containing those daemonset? {pbs_daemonsets_to_remove}",
+                                     raise_error_on_interrupt=True)
+        menu_entry_index = terminal_menu.show()
+        if menu_entry_index != 0:
+            return f'User input: Cancelled removing service {version_to_remove} with daemonset: {pbs_daemonsets_to_remove}'
+
+        console.print(f'\t\tremoving old version {version_to_remove}: {pbs_daemonsets_to_remove}')
+
+        for daemonset in pbs_daemonsets_to_remove:
+            delete_namespaced_daemonset(api_client, daemonset)
 
         return None
